@@ -314,6 +314,63 @@ void BLOSUMmtx( int n, double **matrix, double *freq, unsigned char *amino, char
     for( i=0; i<26; i++ ) amino_grp[(int)amino[i]] = locgrpd[i];
 }
 
+static int checkchar( int i )
+{
+	if( i > 0xff || i <= 0x00 || i == 0x3E || i == 0x3D || i == 0x3C || i == 0x2D || i == 0x20 || i == 0x0d || i == 0x0a )
+		return( 1 );
+	return( 0 );
+}
+
+static void overridematrix( double **matrix )
+{
+	char buf[500];
+	FILE *fp;
+	unsigned int i1, i2;
+	double v;
+	char *bpt;
+	int nread;
+
+	fp = fopen( "_aamtx", "r" );
+	if( fp == NULL )
+	{
+		fprintf( stderr, "Cannot open scorematrix\n" );
+		exit( 1 );
+	}
+
+	while( 1 )
+	{
+		fgets( buf, 499, fp );
+		if( feof( fp ) ) break;
+
+		if( ( bpt = strchr( buf, '#' ) ) ) *bpt = 0;
+
+		i1 = i2 = 0;
+		nread = sscanf( buf, "%x %x %lf", &i1, &i2, &v );
+		if( nread == EOF ) continue;
+		if( nread != 3 )
+		{
+			reporterr( "Format error in this line?\n" );
+			reporterr( "%s\n", buf );
+//			reporterr( "To set a score, 100, for a match of 0x41 and 0x42, \n" );
+//			reporterr( "0x41 0x42 100 \n" );
+			exit( 1 );
+		}
+		if( checkchar( i1 ) )
+		{
+			reporterr( "%c=0x%x cannot be used (1)\n", i1, i1 );
+			exit( 1 );
+		}
+		if( checkchar( i2 ) )
+		{
+			reporterr( "%c=0x%x cannot be used (2)\n", i2, i2 );
+			exit( 1 );
+		}
+		reporterr( "Score(%c=0x%x,%c=0x%x)=%f\n", i1, i1, i2, i2, v );
+		matrix[i1][i2] = v;
+		matrix[i2][i1] = v; // 2018/May/11
+	}
+}
+
 void extendedmtx( double **matrix, double *freq, unsigned char *amino, char *amino_grp )
 {
 	int i;
@@ -336,7 +393,9 @@ void extendedmtx( double **matrix, double *freq, unsigned char *amino, char *ami
 	}
 	for( i=0; i<nalphabets; i++ )
 		matrix[i][i] = matrix[i][i] = (double)1.0;
-#if 0 // user-defined matrix no toki fukkatsu saseru.
+
+	overridematrix( matrix );
+#if 0 // user-defined matrix + user-defined freqency ga aru toki fukkatsu saseru.
 	if( tmpmtx[400] != -1.0 ) 
 	{
 		for( i=0; i<20; i++ ) freq[i] = tmpmtx[400+i];
