@@ -714,6 +714,12 @@ void constants( int nseq, char **seq )
 		fprintf( stdout, "####### average1  = %f\n", average );
 #endif
 
+		if( average < 0.0 )
+		{
+			reporterr( "\nUnrealistic scoring matrix.  Give larger positive values to matches (A/A, B/B, etc).\n\n" );
+			exit( 1 );
+		}
+
 		for( i=0; i<nalphabets; i++ ) for( j=0; j<nalphabets; j++ ) 
 			n_distmp[i][j] *= 600.0 / average;
 #if TEST
