@@ -4,8 +4,6 @@
 
 static int treeout = 0;
 static int maxdist = 1;
-static int nadd = 0;
-static int usenaivescoreinsteadofalignmentscore = 0;
 
 #ifdef enablemultithread
 typedef struct _jobtable
@@ -345,6 +343,14 @@ int main( int argc, char **argv )
 #else
 	getnumlen( infp );
 #endif
+
+	if( njob < 2 )
+	{
+		fprintf( stderr, "At least 2 sequences should be input!\n"
+						 "Only %d sequence found.\n", njob ); 
+		exit( 1 );
+	}
+
 	rewind( infp );
 
 	njob -= nadd; // atarashii hairetsu ha mushi
