@@ -35,6 +35,7 @@ char **arguments( int argc, char *argv[] )
 	devide = 0;
 	fftscore = 1;
 	use_fft = 1;
+	nevermemsave = 0;
 	alg = 'A';
     weight = 0;
     utree = 1;
@@ -81,6 +82,9 @@ char **arguments( int argc, char *argv[] )
 				case 'N':
 					use_fft = 0;
 					break;
+				case 'n':
+					nevermemsave = 1;
+					break;
 				case 'e':
 					fftscore = 0;
 					break;
@@ -105,6 +109,9 @@ char **arguments( int argc, char *argv[] )
 				case 'u':
 					tbrweight = 0;
 					break;
+				case 'U':
+					tbrweight = -1;
+					break;
 				case 'z':
 					fftThreshold = myatoi( *++argv );
 					--argc;
@@ -253,9 +260,9 @@ void GroupAlign( int nseq1, int nseq2, char **name, int *nlen, char **seq, char
 	else
 	{
 		if( alg == 'M' )
-			pscore = MSalignmm( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+			pscore = MSalignmm( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap, NULL, NULL, NULL, 0.0, 0.0 );
 		else
-			pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap, -1, -1 );
+			pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, alloclen, 0, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap, -1, -1, NULL, NULL, NULL, 0.0, 0.0 );
 	}
 #if DEBUG
 		time2 = getrusage_sec();
@@ -364,7 +371,7 @@ int main( int argc, char *argv[] )
 
 	topol = AllocateIntCub( njob, 2, njob );
 	len = AllocateDoubleMtx( njob, 2 );
-	pscore = AllocateDoubleMtx( njob, njob );
+	if( tbrweight > 0 ) pscore = AllocateDoubleMtx( njob, njob );
 	eff = AllocateDoubleVec( njob );
 
 #if 0
@@ -408,31 +415,36 @@ int main( int argc, char *argv[] )
         if( nlen[i] != nlen[nseq1] ) 
             ErrorExit( "group2 is not aligned." );
     }
+
+
     if( tbutree == 0 )
 	{
-		for( i=0; i<nseq1; i++ ) 
+		if( tbrweight > 0 )
 		{
-			for( j=i+1; j<nseq1; j++ )
+			for( i=0; i<nseq1; i++ ) 
 			{
-				pscore[i][j] = (double)substitution_hosei( seq[i], seq[j] );
-//				fprintf( stderr, "%d-%d, %5.1f \n", i, j, pscore[i][j] );
+				for( j=i+1; j<nseq1; j++ )
+				{
+					pscore[i][j] = (double)substitution_hosei( seq[i], seq[j] );
+//					fprintf( stderr, "%d-%d, %5.1f \n", i, j, pscore[i][j] );
+				}
+				for( j=nseq1; j<njob; j++ )
+				{
+					pscore[i][j] = 3.0;
+//					fprintf( stderr, "%d-%d, %5.1f \n", i, j, pscore[i][j] );
+				}
 			}
-			for( j=nseq1; j<njob; j++ )
+			for( i=nseq1; i<njob-1; i++ ) 
 			{
-				pscore[i][j] = 3.0;
-//				fprintf( stderr, "%d-%d, %5.1f \n", i, j, pscore[i][j] );
+				for( j=i+1; j<njob; j++ )
+				{
+					pscore[i][j] = (double)substitution_hosei( seq[i], seq[j] );
+//					fprintf( stderr, "%d-%d, %5.1f \n", i, j, pscore[i][j] );
+				}
 			}
-		}
-		for( i=nseq1; i<njob-1; i++ ) 
-		{
-			for( j=i+1; j<njob; j++ )
-			{
-				pscore[i][j] = (double)substitution_hosei( seq[i], seq[j] );
-//				fprintf( stderr, "%d-%d, %5.1f \n", i, j, pscore[i][j] );
-			}
-		}
-//		fprintf( stderr, "\n" );
+//			fprintf( stderr, "\n" );
 
+		}
 
     }
    	else
@@ -446,27 +458,36 @@ int main( int argc, char *argv[] )
 		fclose( prep );
 #endif
 	}
-	fprintf( stderr, "Constructing dendrogram ... " );
-	if( treemethod == 'x' )
-		veryfastsupg( njob, pscore, topol, len );
-	else
-		ErrorExit( "Incorrect tree\n" );
-	fprintf( stderr, "done.\n" );
 
-	if( tbrweight )
+	if( tbrweight > 0 )
 	{
+		fprintf( stderr, "Constructing dendrogram ... " );
+		if( treemethod == 'x' )
+			veryfastsupg( njob, pscore, topol, len );
+		else
+			ErrorExit( "Incorrect tree\n" );
+		fprintf( stderr, "done.\n" );
+
 		weight = 3;
 		counteff_simple( njob, topol, len, eff );
 //		for( i=0; i<njob; i++ ) fprintf( stderr, "eff[%d] = %f\n", i, eff[i] );
 	}
-	else
+	else if ( tbrweight == 0 )
 	{
 		for( i=0; i<njob; i++ ) eff[i] = 1.0;
 	}
+	else
+	{
+		getweightfromname( njob, eff, name );
+	}
+
+	//for( i=0; i<njob; i++ ) reporterr( "weight[%d] = %f\n", i, eff[i] );
+	//exit( 1 );
 
 	len1 = strlen( seq[0] );
 	len2 = strlen( seq[nseq1] );
-	if( len1 > 30000 || len2 > 30000 )
+	if( !nevermemsave && ( alg != 'M' && ( len1 > 30000 || len2 > 30000  ) ) )
+//	if( len1 > 30000 || len2 > 30000 )
 	{       
 		fprintf( stderr, "\nlen1=%d, len2=%d, Switching to the memsave mode.\n", len1, len2 );
 		alg = 'M';
@@ -474,6 +495,7 @@ int main( int argc, char *argv[] )
         
 
 
+	reporterr( "GroupAglin..\n" );
 
 	GroupAlign( nseq1, nseq2, name, nlen, seq, aseq, mseq1, mseq2, topol, len, eff, alloclen );
 
