@@ -1039,7 +1039,7 @@ static void pairalign( int nseq, int *nlen, char **seq, int *mem1, int *mem2, do
 			case( 'M' ):
 				fprintf( stderr, "\bm" );
 //				fprintf( stderr, "%d-%d", clus1, clus2 );
-				pscore = MSalignmm( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+				pscore = MSalignmm( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap, NULL, NULL, NULL, 0.0, 0.0 );
 				break;
 			case( 'A' ):
 				if( clus1 == 1 && clus2 == 1 )
@@ -1050,7 +1050,7 @@ static void pairalign( int nseq, int *nlen, char **seq, int *mem1, int *mem2, do
 				else
 				{
 //					fprintf( stderr, "%d-%d", clus1, clus2 );
-					pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap, -1, -1 );
+					pscore = A__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, 0, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap, -1, -1, NULL, NULL, NULL, 0.0, 0.0 );
 				}
 				break;
 			default:
